@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 
@@ -64,6 +64,13 @@ stetmesh::TmPatch::TmPatch(std::string const & id, Tetmesh * container,
     throw steps::ArgErr(os.str());
     }
 
+    if (tris.size() ==0)
+    {
+    	std::ostringstream os;
+    	os << "No triangles provided to TmPatch initializer function";
+    	throw steps::ArgErr(os.str());
+    }
+
     // The maximum triangle index in tetrahedral mesh
     uint maxidx = (pTetmesh->countTris() -1);
     // vector to store all triangles to be 'flipped'
@@ -97,6 +104,16 @@ stetmesh::TmPatch::TmPatch(std::string const & id, Tetmesh * container,
     		os << "triangle belongs to a different patch.";
     		throw steps::ArgErr(os.str());
     	}
+
+    	if (pTetmesh->getTriDiffBoundary(tris[i]) != 0)
+    	{
+    		std::ostringstream os;
+    		os << "Cannot add triangle with index " << tris[i] << "(#" << i;
+    		os << " in list) to patch; ";
+    		os << "triangle belongs to a diffusion boundary.";
+    		throw steps::ArgErr(os.str());
+    	}
+
     	// Check if the triangle neighbours belong to the correct compartments
     	// (bearing in mind their relative position might need to be 'flipped';
     	// add to 'flip list' if necessary
