@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // STL headers.
@@ -153,6 +153,32 @@ std::vector<Spec *> Model::getAllSpecs(void) const
 
 ////////////////////////////////////////////////////////////////////////////////
 
+std::vector<Volsys *> Model::getAllVolsyss(void) const
+{
+	VolsysPVec volsyss = VolsysPVec();
+	VolsysPMapCI vsys_end = pVolsys.end();
+	for (VolsysPMapCI vs = pVolsys.begin(); vs != vsys_end; ++vs)
+	{
+		volsyss.push_back(vs->second);
+	}
+	return volsyss;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+std::vector<Surfsys *> Model::getAllSurfsyss(void) const
+{
+	SurfsysPVec surfsyss = SurfsysPVec();
+	SurfsysPMapCI ssys_end = pSurfsys.end();
+	for (SurfsysPMapCI ss = pSurfsys.begin(); ss != ssys_end; ++ss)
+	{
+		surfsyss.push_back(ss->second);
+	}
+	return surfsyss;
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 Volsys * Model::getVolsys(string const & id) const
 {
     VolsysPMapCI volsys = pVolsys.find(id);
