@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 #ifndef STEPS_MODEL_MODEL_HPP
@@ -64,12 +64,20 @@ typedef std::vector<SpecP>               SpecPVec;
 typedef SpecPVec::iterator               SpecPVecI;
 typedef SpecPVec::const_iterator         SpecPVecCI;
 
-typedef Volsys *                        VolsysP;
+typedef Volsys *                         VolsysP;
+typedef std::vector<VolsysP>  			 VolsysPVec;
+typedef VolsysPVec::iterator             VolsysPVecI;
+typedef VolsysPVec::const_iterator       VolsysPVecCI;
+
+typedef Surfsys *                        SurfsysP;
+typedef std::vector<SurfsysP>  			 SurfsysPVec;
+typedef SurfsysPVec::iterator            SurfsysPVecI;
+typedef SurfsysPVec::const_iterator      SurfsysPVecCI;
+
 typedef std::map<std::string, VolsysP>  VolsysPMap;
 typedef VolsysPMap::iterator            VolsysPMapI;
 typedef VolsysPMap::const_iterator      VolsysPMapCI;
 
-typedef Surfsys *                       SurfsysP;
 typedef std::map<std::string, SurfsysP> SurfsysPMap;
 typedef SurfsysPMap::iterator           SurfsysPMapI;
 typedef SurfsysPMap::const_iterator     SurfsysPMapCI;
@@ -163,6 +171,11 @@ public:
     /// \param id ID of the volume system.
 	void delVolsys(std::string const & id);
 
+    /// Return a list of all volume systems in the Model object.
+    ///
+    /// \return List of pointers to the volume systems in the Model object.
+	std::vector<Volsys *> getAllVolsyss(void) const;
+
 	////////////////////////////////////////////////////////////////////////
 	// OPERATIONS: SURFSYS (EXPOSED TO PYTHON)
 	////////////////////////////////////////////////////////////////////////
@@ -178,6 +191,11 @@ public:
     /// \param id ID of the surface system.
 	void delSurfsys(std::string const & id);
 
+    /// Return a list of all surface systems in the Model object.
+    ///
+    /// \return List of pointers to the surface systems in the Model object.
+	std::vector<Surfsys *> getAllSurfsyss(void) const;
+
 	////////////////////////////////////////////////////////////////////////
 	// INTERNAL (NON-EXPOSED): SOLVER HELPER METHODS
 	////////////////////////////////////////////////////////////////////////
