@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // STL headers.
@@ -143,6 +143,13 @@ void  API::setDT(double dt)
 
 ////////////////////////////////////////////////////////////////////////////////
 
+void  API::setRk4DT(double dt)
+{
+	throw steps::NotImplErr();
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 double API::getDT(void) const
 {
 	throw steps::NotImplErr();
@@ -150,6 +157,13 @@ double API::getDT(void) const
 
 ////////////////////////////////////////////////////////////////////////////////
 
+double  API::getRk4DT(void) const
+{
+	throw steps::NotImplErr();
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 double API::getA0(void) const
 {
     throw steps::NotImplErr();
@@ -175,5 +189,19 @@ void API::setNSteps(uint nsteps)
 	throw steps::NotImplErr();
 }
 
+////////////////////////////////////////////////////////////////////////////////
+
+void API::checkpoint(std::string const & file_name)
+{
+	throw steps::NotImplErr();
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void API::restore(std::string const & file_name)
+{
+	throw steps::NotImplErr();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // END
