@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2010Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // STL headers.
@@ -121,6 +121,26 @@ ssolver::Compdef::~Compdef(void)
 
 ////////////////////////////////////////////////////////////////////////////////
 
+void ssolver::Compdef::checkpoint(std::fstream & cp_file)
+{
+    cp_file.write((char*)pPoolCount, sizeof(double) * pSpecsN);
+    cp_file.write((char*)pPoolFlags, sizeof(uint) * pSpecsN);
+    cp_file.write((char*)pReacKcst, sizeof(double) * pReacsN);
+    cp_file.write((char*)pReacFlags, sizeof(uint) * pReacsN);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void ssolver::Compdef::restore(std::fstream & cp_file)
+{
+    cp_file.read((char*)pPoolCount, sizeof(double) * pSpecsN);
+    cp_file.read((char*)pPoolFlags, sizeof(uint) * pSpecsN);
+    cp_file.read((char*)pReacKcst, sizeof(double) * pReacsN);
+    cp_file.read((char*)pReacFlags, sizeof(uint) * pReacsN);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 void ssolver::Compdef::setup_references()
 {
 	assert (pSetupRefsdone == false);
