@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2010Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,14 +23,15 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // STL headers.
 #include <string>
 #include <cassert>
+#include <sstream>
 
 // STEPS headers.
 #include "../common.h"
@@ -60,6 +61,7 @@ ssolver::SReacdef::SReacdef(Statedef * sd, uint idx, steps::model::SReac * sr)
 , pOrhs()
 , pSrhs()
 , pSetupdone(false)
+, pSurface_surface(true)
 , pSpec_I_DEP(0)
 , pSpec_S_DEP(0)
 , pSpec_O_DEP(0)
@@ -82,6 +84,15 @@ ssolver::SReacdef::SReacdef(Statedef * sd, uint idx, steps::model::SReac * sr)
 
     pName = sr->getID();
     pOrder = sr->getOrder();
+
+    if (pOrder == 0)
+    {
+        std::ostringstream os;
+		os << "Model contains zero-order surface reaction, which are not permitted. ";
+		os << "Zero-order volume reaction may be used instead.\n";
+        throw steps::ArgErr(os.str());
+    }
+
     pKcst = sr->getKcst();
     pIlhs = sr->getILHS();
     pOlhs = sr->getOLHS();
@@ -149,6 +160,18 @@ ssolver::SReacdef::~SReacdef(void)
 
 ////////////////////////////////////////////////////////////////////////////////
 
+void ssolver::SReacdef::checkpoint(std::fstream & cp_file)
+{
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void ssolver::SReacdef::restore(std::fstream & cp_file)
+{
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 std::string const ssolver::SReacdef::name(void) const
 {
 	return pName;
@@ -185,6 +208,7 @@ void ssolver::SReacdef::setup(void)
 	smod::SpecPVecCI ol_end = pOlhs.end();
 	for (smod::SpecPVecCI ol = pOlhs.begin(); ol != ol_end; ++ol)
 	{
+		pSurface_surface = false;
 		uint sidx = pStatedef->getSpecIdx(*ol);
 		pSpec_O_LHS[sidx] += 1;
 	}
@@ -192,11 +216,11 @@ void ssolver::SReacdef::setup(void)
 	smod::SpecPVecCI il_end = pIlhs.end();
 	for (smod::SpecPVecCI il = pIlhs.begin(); il != il_end; ++il)
 	{
+		pSurface_surface = false;
 		uint sidx = pStatedef->getSpecIdx(*il);
 		pSpec_I_LHS[sidx] += 1;
 	}
 
-
 	smod::SpecPVecCI sl_end = pSlhs.end();
 	for (smod::SpecPVecCI sl = pSlhs.begin(); sl != sl_end; ++sl)
 	{
