@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // Standard library & STL headers.
@@ -57,6 +57,7 @@ stex::Diff::Diff(ssolver::Diffdef * ddef, stex::Tet * tet)
 , pScaledDcst(0.0)
 , pDcst(0.0)
 , pCDFSelector()
+, pNeighbCompLidx()
 {
 	assert(pDiffdef != 0);
 	assert(pTet != 0);
@@ -68,6 +69,22 @@ stex::Diff::Diff(ssolver::Diffdef * ddef, stex::Tet * tet)
 		pTet->nextTet(3)
 	};
 
+    for (uint i = 0; i < 4; ++i) { pDiffBndDirection[i] = pTet->getDiffBndDirection(i);}
+
+    uint gidx = pDiffdef->lig();
+    for (uint i = 0; i < 4; ++i)
+    {
+        if (next[i] == 0)
+        {
+        	pNeighbCompLidx[i] = -1;
+        	continue;
+        }
+        else
+        {
+        	pNeighbCompLidx[i] = next[i]->compdef()->specG2L(gidx);
+        }
+    }
+
     // Precalculate part of the scaled diffusion constant.
 	uint ldidx = pTet->compdef()->diffG2L(pDiffdef->gidx());
 	double dcst = pTet->compdef()->dcst(ldidx);
@@ -77,12 +94,24 @@ stex::Diff::Diff(ssolver::Diffdef * ddef, stex::Tet * tet)
     for (uint i = 0; i < 4; ++i)
     {
         // Compute the scaled diffusion constant.
+    	// Need to here check if the direction is a diffusion boundary
         double dist = pTet->dist(i);
         if ((dist > 0.0) && (next[i] != 0))
-            d[i] = (pTet->area(i) * dcst) / (pTet->vol() * dist);
+        {
+        	if (pDiffBndDirection[i] == true)
+        	{
+        		if (pDiffBndActive[i]) d[i] = (pTet->area(i) * dcst) / (pTet->vol() * dist);
+        		else d[i] = 0.0;
+        	}
+        	else d[i] = (pTet->area(i) * dcst) / (pTet->vol() * dist);
+        }
     }
     // Compute scaled "diffusion constant".
-    pScaledDcst = d[0] + d[1] + d[2] + d[3];
+    for (uint i = 0; i < 4; ++i)
+    {
+		pScaledDcst += d[i];
+	}
+
     // Should not be negative!
     assert(pScaledDcst >= 0);
 
@@ -109,6 +138,30 @@ stex::Diff::~Diff(void)
 
 ////////////////////////////////////////////////////////////////////////////////
 
+void stex::Diff::checkpoint(std::fstream & cp_file)
+{
+    cp_file.write((char*)&pScaledDcst, sizeof(double));
+    cp_file.write((char*)&pDcst, sizeof(double));
+    cp_file.write((char*)pCDFSelector, sizeof(double) * 3);
+    cp_file.write((char*)pDiffBndActive, sizeof(bool) * 4);
+    cp_file.write((char*)pDiffBndDirection, sizeof(bool) * 4);
+    cp_file.write((char*)pNeighbCompLidx, sizeof(int) * 4);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void stex::Diff::restore(std::fstream & cp_file)
+{
+    cp_file.read((char*)&pScaledDcst, sizeof(double));
+    cp_file.read((char*)&pDcst, sizeof(double));
+    cp_file.read((char*)pCDFSelector, sizeof(double) * 3);
+    cp_file.read((char*)pDiffBndActive, sizeof(bool) * 4);
+    cp_file.read((char*)pDiffBndDirection, sizeof(bool) * 4);
+    cp_file.read((char*)pNeighbCompLidx, sizeof(int) * 4);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 void stex::Diff::setupDeps(void)
 {
     // We will check all KProcs of the following simulation elements:
@@ -215,11 +268,44 @@ void stex::Diff::reset(void)
 {
     resetExtent();
 
+    // NOTE: These must become the dcst calculation for obvious reasons
+    pDiffBndActive[0] = false;
+    pDiffBndActive[1] = false;
+    pDiffBndActive[2] = false;
+    pDiffBndActive[3] = false;
+
     uint ldidx = pTet->compdef()->diffG2L(pDiffdef->gidx());
 	double dcst = pTet->compdef()->dcst(ldidx);
     setDcst(dcst);
 
     setActive(true);
+
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void stex::Diff::setDiffBndActive(uint i, bool active)
+{
+	assert (i < 4);
+	assert(pDiffBndDirection[i] == true);
+
+	// Only need to update if the flags are changing
+	if (pDiffBndActive[i] != active)
+	{
+		pDiffBndActive[i] = active;
+		setDcst(pDcst);
+	}
+
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+bool stex::Diff::getDiffBndActive(uint i) const
+{
+	assert (i < 4);
+	assert(pDiffBndDirection[i] == true);
+
+	return pDiffBndActive[i];
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -238,15 +324,30 @@ void stex::Diff::setDcst(double dcst)
 	};
 
     double d[4] = { 0.0, 0.0, 0.0, 0.0 };
+
     for (uint i = 0; i < 4; ++i)
     {
         // Compute the scaled diffusion constant.
+    	// Need to here check if the direction is a diffusion boundary
         double dist = pTet->dist(i);
         if ((dist > 0.0) && (next[i] != 0))
-            d[i] = (pTet->area(i) * dcst) / (pTet->vol() * dist);
+        {
+        	if (pDiffBndDirection[i] == true)
+        	{
+        		if (pDiffBndActive[i]) d[i] = (pTet->area(i) * dcst) / (pTet->vol() * dist);
+        		else d[i] = 0.0;
+        	}
+        	else d[i] = (pTet->area(i) * dcst) / (pTet->vol() * dist);
+        }
     }
+
     // Compute scaled "diffusion constant".
-    pScaledDcst = d[0] + d[1] + d[2] + d[3];
+    pScaledDcst = 0.0;
+
+    for (uint i = 0; i < 4; ++i)
+    {
+    	pScaledDcst += d[i];
+	}
     // Should not be negative!
     assert(pScaledDcst >= 0);
 
@@ -294,11 +395,11 @@ std::vector<uint> const & stex::Diff::apply(steps::rng::RNG * rng)
     // Fetch the ligand as global index.
     uint gidx = pDiffdef->lig();
     // As local index.
-    uint lidx = cdef->specG2L(gidx);
+    uint lidx_pTet = cdef->specG2L(gidx);
 
     // Apply local change.
-    uint * local = pTet->pools() + lidx;
-	bool clamped = pTet->clamped(lidx);
+    uint * local = pTet->pools() + lidx_pTet;
+	bool clamped = pTet->clamped(lidx_pTet);
 
     if (clamped == false)
     {
@@ -314,11 +415,13 @@ std::vector<uint> const & stex::Diff::apply(steps::rng::RNG * rng)
         // If there is no next tet 0, pCDFSelector[0] should be zero
         // So we can assert that nextet 0 does indeed exist
         assert (nexttet != 0);
-        if (nexttet->clamped(lidx) == false)
+        assert(pNeighbCompLidx[0] > -1);
+
+        if (nexttet->clamped(pNeighbCompLidx[0]) == false)
         {
-            nexttet->incCount(lidx,1);
+            nexttet->incCount(pNeighbCompLidx[0],1);
         }
-        if (clamped == false) {pTet->incCount(lidx, -1); }
+        if (clamped == false) {pTet->incCount(lidx_pTet, -1); }
 
         rExtent++;
         return pUpdVec[0];
@@ -330,11 +433,13 @@ std::vector<uint> const & stex::Diff::apply(steps::rng::RNG * rng)
         // If there is no next tet 1, pCDFSelector[1] should be zero
         // So we can assert that nextet 1 does indeed exist
         assert (nexttet != 0);
-        if (nexttet->clamped(lidx) == false)
+        assert(pNeighbCompLidx[1] > -1);
+
+        if (nexttet->clamped(pNeighbCompLidx[1]) == false)
         {
-            nexttet->incCount(lidx,1);
+            nexttet->incCount(pNeighbCompLidx[1],1);
         }
-        if (clamped == false) {pTet->incCount(lidx, -1); }
+        if (clamped == false) {pTet->incCount(lidx_pTet, -1); }
 
         rExtent++;
         return pUpdVec[1];
@@ -346,11 +451,13 @@ std::vector<uint> const & stex::Diff::apply(steps::rng::RNG * rng)
         // If there is no next tet 2, pCDFSelector[2] should be zero
         // So we can assert that nextet 2 does indeed exist
         assert (nexttet != 0);
-        if (nexttet->clamped(lidx) == false)
+        assert(pNeighbCompLidx[2] > -1);
+
+        if (nexttet->clamped(pNeighbCompLidx[2]) == false)
         {
-            nexttet->incCount(lidx,1);
+            nexttet->incCount(pNeighbCompLidx[2],1);
         }
-        if (clamped == false) {pTet->incCount(lidx, -1); }
+        if (clamped == false) {pTet->incCount(lidx_pTet, -1); }
 
         rExtent++;
         return pUpdVec[2];
@@ -362,11 +469,13 @@ std::vector<uint> const & stex::Diff::apply(steps::rng::RNG * rng)
         // If there is no next tet 3, pCDFSelector[3] should be zero
         // So we can assert that nextet 3 does indeed exist
         assert (nexttet != 0);
-        if (nexttet->clamped(lidx) == false)
+        assert(pNeighbCompLidx[3] > -1);
+
+        if (nexttet->clamped(pNeighbCompLidx[3]) == false)
         {
-            nexttet->incCount(lidx,1);
+            nexttet->incCount(pNeighbCompLidx[3],1);
         }
-        if (clamped == false) {pTet->incCount(lidx, -1); }
+        if (clamped == false) {pTet->incCount(lidx_pTet, -1); }
 
         rExtent++;
         return pUpdVec[3];
