@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 
@@ -49,12 +49,25 @@ NAMESPACE_ALIAS(steps::math, smath);
 
 ////////////////////////////////////////////////////////////////////////////////
 
-static inline double comp_ccst(double kcst, double vol, uint order)
+static inline double comp_ccst(double kcst, double vol, uint order, double compvol)
 {
     double vscale = 1.0e3 * vol * smath::AVOGADRO;
     int o1 = static_cast<int>(order) - 1;
-    if (o1 < 0) o1 = 0;
-    return kcst * pow(vscale, static_cast<double>(-o1));
+
+    // IMPORTANT: Now treating zero-order reaction units correctly, i.e. as
+    // M/s not /s
+    // if (o1 < 0) o1 = 0;
+
+    // BUGFIX, IH 15/8/2010. Incorrect for zero-order reactions:
+    // rate was the same for all tets, not a fraction of the total volume
+    // return kcst * pow(vscale, static_cast<double>(-o1));
+
+    double ccst = kcst * pow(vscale, static_cast<double>(-o1));
+
+    // Special case for zero-order reactions right now:
+    // if (order == 0) ccst *= (vol/compvol);
+
+    return ccst;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -73,7 +86,7 @@ stex::Reac::Reac(ssolver::Reacdef * rdef, stex::Tet * tet)
 	uint lridx = pTet->compdef()->reacG2L(pReacdef->gidx());
 	double kcst = pTet->compdef()->kcst(lridx);
 	pKcst = kcst;
-	pCcst = comp_ccst(kcst, pTet->vol(), pReacdef->order());
+	pCcst = comp_ccst(kcst, pTet->vol(), pReacdef->order(), pTet->compdef()->vol());
 	assert (pCcst >= 0.0);
 }
 
@@ -85,6 +98,22 @@ stex::Reac::~Reac(void)
 
 ////////////////////////////////////////////////////////////////////////////////
 
+void stex::Reac::checkpoint(std::fstream & cp_file)
+{
+    cp_file.write((char*)&pCcst, sizeof(double));
+    cp_file.write((char*)&pKcst, sizeof(double));
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void stex::Reac::restore(std::fstream & cp_file)
+{
+    cp_file.read((char*)&pCcst, sizeof(double));
+    cp_file.read((char*)&pKcst, sizeof(double));
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 void stex::Reac::reset(void)
 {
     resetExtent();
@@ -100,7 +129,7 @@ void stex::Reac::resetCcst(void)
 	double kcst = pTet->compdef()->kcst(lridx);
 	// Also reset kcst
 	pKcst = kcst;
-	pCcst = comp_ccst(kcst, pTet->vol(), pReacdef->order());
+	pCcst = comp_ccst(kcst, pTet->vol(), pReacdef->order(), pTet->compdef()->vol());
 	assert (pCcst >= 0.0);
 }
 
@@ -110,7 +139,7 @@ void stex::Reac::setKcst(double k)
 {
 	assert (k >= 0.0);
 	pKcst = k;
-	pCcst = comp_ccst(k, pTet->vol(), pReacdef->order());
+	pCcst = comp_ccst(k, pTet->vol(), pReacdef->order(), pTet->compdef()->vol());
 	assert (pCcst >= 0.0);
 }
 
