@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -24,9 +24,9 @@
 
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // Standard library & STL headers.
@@ -57,12 +57,13 @@ NAMESPACE_ALIAS(steps::solver, ssolver);
 
 stex::Tet::Tet
 (
-    solver::Compdef * cdef, double vol,
+    uint idx, solver::Compdef * cdef, double vol,
     double a0, double a1, double a2, double a3,
     double d0, double d1, double d2, double d3,
     int tet0, int tet1, int tet2, int tet3
 )
-: pCompdef(cdef)
+: pIdx(idx)
+, pCompdef(cdef)
 , pVol(vol)
 , pTets()
 //, pTris()
@@ -107,6 +108,7 @@ stex::Tet::Tet
     pPoolFlags = new uint[nspecs];
     std::fill_n(pPoolCount, nspecs, 0);
     std::fill_n(pPoolFlags, nspecs, 0);
+    std::fill_n(pDiffBndDirection, 4, false);
     pKProcs.resize(compdef()->countDiffs() + compdef()->countReacs());
 
 }
@@ -126,8 +128,33 @@ stex::Tet::~Tet(void)
 
 ////////////////////////////////////////////////////////////////////////////////
 
+void stex::Tet::checkpoint(std::fstream & cp_file)
+{
+    uint nspecs = compdef()->countSpecs();
+    cp_file.write((char*)pPoolCount, sizeof(uint) * nspecs);
+    cp_file.write((char*)pPoolFlags, sizeof(uint) * nspecs);
+
+    KProcPVecCI e = pKProcs.end();
+    for (KProcPVecCI i = pKProcs.begin(); i != e; ++i) (*i)->checkpoint(cp_file);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void stex::Tet::restore(std::fstream & cp_file)
+{
+    uint nspecs = compdef()->countSpecs();
+    cp_file.read((char*)pPoolCount, sizeof(uint) * nspecs);
+    cp_file.read((char*)pPoolFlags, sizeof(uint) * nspecs);
+
+    KProcPVecCI e = pKProcs.end();
+    for (KProcPVecCI i = pKProcs.begin(); i != e; ++i) (*i)->restore(cp_file);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 void stex::Tet::setNextTet(uint i, stex::Tet * t)
 {
+	/*
     if (t->compdef() != compdef())
     {
         pNextTet[i] = 0;
@@ -138,8 +165,24 @@ void stex::Tet::setNextTet(uint i, stex::Tet * t)
         if (pNextTri[i] != 0) std::cout << "WARNING: writing over nextTri index " << i;
         pNextTri[i] = 0;
     }
+    */
+
+	// Now adding all tets, even those from other compartments, due to the diffusion boundaries
+    pNextTet[i] = t;
+    if (pNextTri[i] != 0) std::cout << "WARNING: writing over nextTri index " << i;
+    pNextTri[i] = 0;
+
+
 }
 
+////////////////////////////////////////////////////////////////////////////////
+
+void stex::Tet::setDiffBndDirection(uint i)
+{
+	assert(i < 4);
+
+	pDiffBndDirection[i] = true;
+}
 
 ////////////////////////////////////////////////////////////////////////////////
 
