@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 #ifndef STEPS_TETEXACT_TET_HPP
@@ -34,6 +34,7 @@
 // STL headers.
 #include <cassert>
 #include <vector>
+#include <fstream>
 
 // STEPS headers.
 #include "../common.h"
@@ -78,17 +79,29 @@ public:
 
     Tet
     (
-        steps::solver::Compdef * cdef, double vol,
+        uint idx, steps::solver::Compdef * cdef, double vol,
         double a0, double a1, double a2, double a3,
         double d0, double d1, double d2, double d3,
         int tet0, int tet1, int tet2, int tet3
     );
     ~Tet(void);
 
+    ////////////////////////////////////////////////////////////////////////
+    // CHECKPOINTING
+    ////////////////////////////////////////////////////////////////////////
+    /// checkpoint data
+    void checkpoint(std::fstream & cp_file);
+
+    /// restore data
+    void restore(std::fstream & cp_file);
+
     ////////////////////////////////////////////////////////////////////////
     // SETUP
     ////////////////////////////////////////////////////////////////////////
 
+    inline uint idx(void) const
+    { return pIdx; }
+
     /// Set pointer to the next neighbouring tetrahedron.
     ///
     void setNextTet(uint i, stex::Tet * t);
@@ -171,6 +184,12 @@ public:
     inline int tet(uint t)
     { return pTets[t]; }
 
+    // Set whether a direction is a diffusion boundary
+    void setDiffBndDirection(uint i);
+
+    inline bool getDiffBndDirection(uint idx) const
+    { return pDiffBndDirection[idx]; }
+
     /*
     inline uint tri(uint t)
     { return pTris[t]; }
@@ -182,6 +201,7 @@ private:
 
     ////////////////////////////////////////////////////////////////////////
 
+	uint 								pIdx;
     /// Type of tetrahedron.
     steps::solver::Compdef            * pCompdef;
 
@@ -209,6 +229,9 @@ private:
     /// The kinetic processes.
     std::vector<stex::KProc *>          pKProcs;
 
+    /// Flag if a direction is a diffusion boundary direction
+    bool  								pDiffBndDirection[4];
+
     ////////////////////////////////////////////////////////////////////////
 
 };
