@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -23,9 +23,9 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // Standard library & STL headers.
@@ -52,9 +52,10 @@ NAMESPACE_ALIAS(steps::solver, ssolver);
 
 ////////////////////////////////////////////////////////////////////////////////
 
-stex::Tri::Tri(steps::solver::Patchdef * patchdef, double area,
+stex::Tri::Tri(uint idx, steps::solver::Patchdef * patchdef, double area,
 			   int tetinner, int tetouter)
-: pPatchdef(patchdef)
+: pIdx(idx)
+, pPatchdef(patchdef)
 , pArea(area)
 , pInnerTet(0)
 , pOuterTet(0)
@@ -90,6 +91,30 @@ stex::Tri::~Tri(void)
 
 ////////////////////////////////////////////////////////////////////////////////
 
+void stex::Tri::checkpoint(std::fstream & cp_file)
+{
+    uint nspecs = patchdef()->countSpecs();
+    cp_file.write((char*)pPoolCount, sizeof(uint) * nspecs);
+    cp_file.write((char*)pPoolFlags, sizeof(uint) * nspecs);
+
+    KProcPVecCI e = pKProcs.end();
+    for (KProcPVecCI i = pKProcs.begin(); i != e; ++i) (*i)->checkpoint(cp_file);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void stex::Tri::restore(std::fstream & cp_file)
+{
+    uint nspecs = patchdef()->countSpecs();
+    cp_file.read((char*)pPoolCount, sizeof(uint) * nspecs);
+    cp_file.read((char*)pPoolFlags, sizeof(uint) * nspecs);
+
+    KProcPVecCI e = pKProcs.end();
+    for (KProcPVecCI i = pKProcs.begin(); i != e; ++i) (*i)->restore(cp_file);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
 void stex::Tri::setInnerTet(stex::Tet * t)
 {
 	pInnerTet = t;
