@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // STEPS - STochastic Engine for Pathway Simulation
-// Copyright (C) 2007-2009Okinawa Institute of Science and Technology, Japan.
+// Copyright (C) 2007-2011Okinawa Institute of Science and Technology, Japan.
 // Copyright (C) 2003-2006University of Antwerp, Belgium.
 //
 // See the file AUTHORS for details.
@@ -24,9 +24,9 @@
 
 
 /*
- *  Last Changed Rev:  $Rev: 349 $
- *  Last Changed Date: $Date: 2010-06-08 10:24:51 +0900 (Tue, 08 Jun 2010) $
- *  Last Changed By:   $Author: wchen $
+ *  Last Changed Rev:  $Rev: 410 $
+ *  Last Changed Date: $Date: 2011-04-07 16:11:28 +0900 (Thu, 07 Apr 2011) $
+ *  Last Changed By:   $Author: iain $
  */
 
 // Standard library & STL headers.
@@ -52,7 +52,11 @@ static inline double comp_ccst(double kcst, double vol, uint order)
 {
     double vscale = 1.0e3 * vol * smath::AVOGADRO;
     int o1 = static_cast<int>(order) - 1;
-    if (o1 < 0) o1 = 0;
+
+    // IMPORTANT: Now treating zero-order reaction units correctly, i.e. as
+    // M/s not /s
+    // if (o1 < 0) o1 = 0;
+
     return kcst * pow(vscale, static_cast<double>(-o1));
 }
 
@@ -79,6 +83,21 @@ swmd::Reac::~Reac(void)
 {
 }
 
+
+////////////////////////////////////////////////////////////////////////////////
+
+void swmd::Reac::checkpoint(std::fstream & cp_file)
+{
+    cp_file.write((char*)&pCcst, sizeof(double));
+}
+
+////////////////////////////////////////////////////////////////////////////////
+
+void swmd::Reac::restore(std::fstream & cp_file)
+{
+    cp_file.read((char*)&pCcst, sizeof(double));
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 
 bool swmd::Reac::active(void) const
